SignInUpController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • SignInUpController
Implemented types

Constructors

SignInUpController()

Properties

credentials ↔ Rx<SignUpDetails>
Credentials Will Return the Details
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
listeners int
no setterinherited
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
otpValue ↔ RxString
getter/setter pair
phoneNumber ↔ RxString
getter/setter pair
routeStack ↔ RxList<PageView>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectCountryCode ↔ RxString
getter/setter pair
showButtonLoader ↔ RxBool
getter/setter pair
userEmail ↔ RxString
getter/setter pair
userId ↔ RxString
getter/setter pair
userName ↔ RxString
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
backOnOtpView(BuildContext context) → dynamic
backOnPhoneView(BuildContext context) → dynamic
backOnSignUpView(BuildContext context) → dynamic
closeAllRoutes(BuildContext context, UserData userData, SignUpStatus type) → void
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
moveToOtpPage(BuildContext context) → dynamic
moveToPhonePage(BuildContext context) → dynamic
moveToSignUpPage(BuildContext context) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onInitCall(BuildContext context) → dynamic
onLoginButtonClick(BuildContext context) → void
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
onSignUpButtonClick(BuildContext context) → void
onVerifyOtpButtonClick({required String pin, required BuildContext context}) → void
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
reset() → void
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited