SocialSignupRequest class

Constructors

SocialSignupRequest({String? deviceId, String? deviceToken, String? deviceType, String? email, String? facebookId, String? firstName, String? imageUrl, String? lang, String? lastName, double? latitude, double? longitude, int? requestType})
SocialSignupRequest.fromJson(Map<String, dynamic> json)

Properties

deviceId String?
getter/setter pair
deviceToken String?
getter/setter pair
deviceType String?
getter/setter pair
email String?
getter/setter pair
facebookId String?
getter/setter pair
firstName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
getter/setter pair
lang String?
getter/setter pair
lastName String?
getter/setter pair
latitude double?
getter/setter pair
longitude double?
getter/setter pair
requestType int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited