ResponseData class

Constructors

ResponseData({String? userId, String? name, String? email, String? countryCode, String? mobile, String? profileUrl, String? rslId})
ResponseData.fromJson(Map<String, dynamic> json)

Properties

countryCode String?
getter/setter pair
email String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mobile String?
getter/setter pair
name String?
getter/setter pair
profileUrl String?
getter/setter pair
rslId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited