VerifyOtpRequestData class

Constructors

VerifyOtpRequestData({String? countryCode, String? deviceId, String? deviceToken, String? deviceType, String? email, String? emailChange, String? lang, String? numberChange, String? otp, String? phone})
VerifyOtpRequestData.fromJson(Map<String, dynamic> json)

Properties

countryCode String?
getter/setter pair
deviceId String?
getter/setter pair
deviceToken String?
getter/setter pair
deviceType String?
getter/setter pair
email String?
getter/setter pair
emailChange String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lang String?
getter/setter pair
numberChange String?
getter/setter pair
otp String?
getter/setter pair
phone String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited