VerifyPhoneRequestData class

Constructors

VerifyPhoneRequestData({String? countryCode, String? deviceId, String? deviceToken, String? deviceType, String? facebookId, String? lang, double? latitude, double? longitude, String? phone, List<String>? usedPhone, String? email, int? verifyType})
VerifyPhoneRequestData.fromJson(Map<String, dynamic> json)

Properties

countryCode String?
getter/setter pair
deviceId String?
getter/setter pair
deviceToken String?
getter/setter pair
deviceType String?
getter/setter pair
email String?
getter/setter pair
facebookId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lang String?
getter/setter pair
latitude double?
getter/setter pair
longitude double?
getter/setter pair
phone String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usedPhone List<String>?
getter/setter pair
verifyType int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited